==> shardingsphere-infra-executor-5.1.2-sources.jar: org/apache/shardingsphere/infra/executor/sql/execute/engine/raw/callback/RawExecutorCallbackFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.executor.sql.execute.engine.raw.callback;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.apache.shardingsphere.spi.ShardingSphereServiceLoader;

import java.util.Collection;

/**
 * Raw executor callback factory.
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public final class RawExecutorCallbackFactory {
    
    static {
        ShardingSphereServiceLoader.register(RawExecutorCallback.class);
    }
    
    /**
     * Get all instances of raw executor callback.
     * 
     * @return got instances
     */
    @SuppressWarnings("rawtypes")
    public static Collection<RawExecutorCallback> getAllInstances() {
        return ShardingSphereServiceLoader.getServiceInstances(RawExecutorCallback.class);
    }
}

==> shardingsphere-infra-executor-5.2.1-sources.jar: org/apache/shardingsphere/infra/executor/sql/execute/engine/raw/callback/RawExecutorCallbackFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.executor.sql.execute.engine.raw.callback;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.apache.shardingsphere.infra.util.spi.ShardingSphereServiceLoader;

import java.util.Collection;

/**
 * Raw executor callback factory.
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public final class RawExecutorCallbackFactory {
    
    static {
        ShardingSphereServiceLoader.register(RawExecutorCallback.class);
    }
    
    /**
     * Get all instances of raw executor callback.
     * 
     * @return got instances
     */
    @SuppressWarnings("rawtypes")
    public static Collection<RawExecutorCallback> getAllInstances() {
        return ShardingSphereServiceLoader.getServiceInstances(RawExecutorCallback.class);
    }
}
